==> aspose_words_cloud-20.10.1.tar.gz: lib/src/requests/upload_file_request.dart <==
/*
 * --------------------------------------------------------------------------------
 * <copyright company="Aspose" file="upload_file_request.dart">
 *   Copyright (c) 2020 Aspose.Words for Cloud
 * </copyright>
 * <summary>
 *   Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to deal
 *  in the Software without restriction, including without limitation the rights
 *  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 * 
 *  The above copyright notice and this permission notice shall be included in all
 *  copies or substantial portions of the Software.
 * 
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *  SOFTWARE.
 * </summary>
 * --------------------------------------------------------------------------------
 */

library aspose_words_cloud;

import 'dart:convert';
import 'dart:typed_data';
import '../../aspose_words_cloud.dart';
import '../api_client.dart';
import '../api_request_data.dart';
import '../api_request_part.dart';

/// Request model for UploadFile operation.
class UploadFileRequest implements RequestBase {
  /// File to upload.
  final ByteData fileContent;

  /// Path where to upload including filename and extension e.g. /file.ext or /Folder 1/file.ext
  /// If the content is multipart and path does not contains the file name it tries to get them from filename parameter
  /// from Content-Disposition header.
  final String path;

  /// Storage name.
  final String storageName;

  UploadFileRequest(final ByteData this.fileContent, final String this.path, {final String this.storageName = null});

  @override
  ApiRequestData createRequestData(final ApiClient apiClient) {
    String path = '/words/storage/file/{path}';
    Map<String, String> queryParams = new Map<String, String>();
    Map<String, String> headers = new Map<String, String>();
    List<ApiRequestPart> bodyParts = new List<ApiRequestPart>();
    if (this.path == null) {
      throw new ApiException(400, 'Parameter path is required.');
    }
    path = path.replaceAll('{path}', apiClient.serializeToString(this.path));
    if (this.storageName != null) {
      queryParams['storageName'] = apiClient.serializeToString(this.storageName);
    }

    if (this.fileContent != null) {
      bodyParts.add(new ApiRequestPart(apiClient.serializeBody(this.fileContent), 'application/octet-stream', name: 'FileContent'));
    }
    else {
      throw new ApiException(400, 'Parameter fileContent is required.');
    }

    String url = apiClient.configuration.getApiRootUrl() + apiClient.applyQueryParams(path, queryParams).replaceAll('//', '/');
    ByteData body = apiClient.serializeBodyParts(bodyParts, headers);
    return new ApiRequestData('PUT', url, headers, body);
  }

  @override
  dynamic deserializeResponse(final ByteData _body) {
    var _result = new FilesUploadResult();
    var _jsonData = utf8.decode(_body.buffer.asUint8List(_body.offsetInBytes, _body.lengthInBytes));
    var _json = jsonDecode(_jsonData);
    _result.deserialize(_json);
    return _result;
  }
}

==> aspose_words_cloud-20.10.2.tar.gz: lib/src/requests/upload_file_request.dart <==
/*
 * --------------------------------------------------------------------------------
 * <copyright company="Aspose" file="upload_file_request.dart">
 *   Copyright (c) 2020 Aspose.Words for Cloud
 * </copyright>
 * <summary>
 *   Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to deal
 *  in the Software without restriction, including without limitation the rights
 *  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 * 
 *  The above copyright notice and this permission notice shall be included in all
 *  copies or substantial portions of the Software.
 * 
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *  SOFTWARE.
 * </summary>
 * --------------------------------------------------------------------------------
 */

library aspose_words_cloud;

import 'dart:convert';
import 'dart:typed_data';
import '../../aspose_words_cloud.dart';
import '../api_client.dart';
import '../api_request_data.dart';
import '../api_request_part.dart';

/// Request model for UploadFile operation.
class UploadFileRequest implements RequestBase {
  /// File to upload.
  final ByteData fileContent;

  /// Path where to upload including filename and extension e.g. /file.ext or /Folder 1/file.ext
  /// If the content is multipart and path does not contains the file name it tries to get them from filename parameter
  /// from Content-Disposition header.
  final String path;

  /// Storage name.
  final String storageName;

  UploadFileRequest(final this.fileContent, final this.path, {final this.storageName});

  @override
  ApiRequestData createRequestData(final ApiClient apiClient) {
    var _path = '/words/storage/file/{path}';
    var _queryParams = <String, String>{};
    var _headers = <String, String>{};
    var _bodyParts = <ApiRequestPart>[];
    if (path == null) {
      throw ApiException(400, 'Parameter path is required.');
    }
    _path = _path.replaceAll('{path}', apiClient.serializeToString(path));
    if (storageName != null) {
      _queryParams['storageName'] = apiClient.serializeToString(storageName);
    }

    if (fileContent != null) {
      _bodyParts.add(ApiRequestPart(apiClient.serializeBody(fileContent), 'application/octet-stream', name: 'FileContent'));
    }
    else {
      throw ApiException(400, 'Parameter fileContent is required.');
    }

    var _url = apiClient.configuration.getApiRootUrl() + apiClient.applyQueryParams(_path, _queryParams).replaceAll('//', '/');
    var _body = apiClient.serializeBodyParts(_bodyParts, _headers);
    return ApiRequestData('PUT', _url, _headers, _body);
  }

  @override
  dynamic deserializeResponse(final ByteData _body) {
    var _result = FilesUploadResult();
    var _jsonData = utf8.decode(_body.buffer.asUint8List(_body.offsetInBytes, _body.lengthInBytes));
    var _json = jsonDecode(_jsonData);
    _result.deserialize(_json);
    return _result;
  }
}
